@@ -251,7 +251,13 @@ class CommitRange:
         ''', re.VERBOSE | re.DOTALL)
     EXTRACTOR_INDICATOR_RE = re.compile(r'(?:Fix|Add)\s+Extractors?', re.IGNORECASE)
     REVERT_RE = re.compile(r'(?:\[[^\]]+\]\s+)?(?i:Revert)\s+([\da-f]{40})')
-    FIXES_RE = re.compile(r'(?i:(?:bug\s*)?fix(?:es)?(?:\s+bugs?)?(?:\s+in|\s+for)?|Improve)\s+([\da-f]{40})')
+    FIXES_RE = re.compile(r'''
+        (?i:
+            (?:bug\s*)?fix(?:es)?(?:
+                \s+(?:bugs?|regression(?:\s+introduced)?)
+            )?(?:\s+(?:in|for|from|by))?
+            |Improve
+        )\s+([\da-f]{40})''', re.VERBOSE)
     UPSTREAM_MERGE_RE = re.compile(r'Update to ytdl-commit-([\da-f]+)')
 
     def __init__(self, start, end, default_author=None):
@@ -353,6 +359,13 @@ class CommitRange:
                     continue
                 commit = Commit(override_hash, override['short'], override.get('authors') or [])
                 logger.info(f'CHANGE {self._commits[commit.hash]} -> {commit}')
+                if match := self.FIXES_RE.search(commit.short):
+                    fix_commitish = match.group(1)
+                    if fix_commitish in self._commits:
+                        del self._commits[commit.hash]
+                        self._fixes[fix_commitish].append(commit)
+                        logger.info(f'Found fix for {fix_commitish[:HASH_LENGTH]}: {commit.hash[:HASH_LENGTH]}')
+                        continue
                 self._commits[commit.hash] = commit
 
         self._commits = dict(reversed(self._commits.items()))
@@ -373,7 +386,7 @@ class CommitRange:
             issues = [issue.strip()[1:] for issue in issues.split(',')] if issues else []
 
             if prefix:
-                groups, details, sub_details = zip(*map(self.details_from_prefix, prefix.split(',')))
+                groups, details, sub_details = zip(*map(self.details_from_prefix, prefix.split(',')), strict=True)
                 group = next(iter(filter(None, groups)), None)
                 details = ', '.join(unique(details))
                 sub_details = list(itertools.chain.from_iterable(sub_details))
